Contains the result of a physics raycast.

* `P`: Position of the raycast hit
* `N`: Normal of the raycast hit
* `Node`: Node hit by the raycast
* `t`: Parametric value of the intersection, ratio of the distance to the hit by the length of the raycast